@@ -25,7 +25,6 @@
 #include <asm/io.h>
 #include <asm/irq.h>
 #include <asm/atomic.h>
-#include <asm/system.h>
 #include <linux/version.h>
 #include <linux/ioport.h>
 #include <linux/sched.h>
@@ -34,6 +33,7 @@
 #include <linux/netdevice.h>
 #include <linux/skbuff.h>
 #include <linux/kernel.h>
+#include <linux/module.h>
 #include <linux/smp.h>
 #include <linux/ctype.h>
 #include <linux/string.h>
@@ -103,7 +103,11 @@ static atomic_t			crit_level		= ATOMIC_INIT (0);
 static unsigned long		crit_flags;
 static atomic_t			scheduler_enabled	= ATOMIC_INIT (0);
 static atomic_t			scheduler_id		= ATOMIC_INIT (-1);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,39)
+static DEFINE_SPINLOCK(stack_lock);
+#else
 static spinlock_t		stack_lock		= SPIN_LOCK_UNLOCKED;
+#endif
 #if !defined (__fcclassic__)
 static int			card_id			= 0;
 #endif
